/*
    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

#pragma once

#define DEFAULT_LOG_FOLDER "/var/log"

/**
 * Icon name of KSystemLog
 */
#define KSYSTEMLOG_ICON "utilities-log-viewer"

/**
 * Icon name of No Mode icon
 */
#define NO_MODE_ICON "text-x-generic"
